@@ -71,7 +71,7 @@ class CacheFileRequest(object):
                     else:
                         return True
             else:
-                logger.debug(f"缓存文件不存在。 {cache_file_path}")
+                logger.debug(f"缓存文件不存在。 {request.url}")
                 return False
 
         if should_read_cache(request, spider):
@@ -112,7 +112,7 @@ class CacheFileRequest(object):
                     # logger.debug(f"不是排除的URL不重写缓存。 {cache_file_path}")
                     return False
             else:
-                logger.debug(f"缓存文件不存在。写缓存。 {cache_file_path}")
+                logger.debug(f"缓存文件不存在。写缓存。 {request.url}")
                 return True
 
         if response.status < 300:
